@@ -10,8 +10,3 @@ from .libpsp import *  # noqa: F401, F403
 from .core import *  # noqa: F401, F403
 from .core._version import __version__  # noqa: F401
 from .widget import *  # noqa: F401, F403
-
-try:
-    from .node import *  # noqa: F401, F403
-except ImportError:
-    pass
