@@ -106,6 +106,7 @@ PYBIND11_MODULE(libbinding, m)
         .def("get_aggregates", &View<t_ctxunit>::get_aggregates)
         .def("get_filter", &View<t_ctxunit>::get_filter)
         .def("get_sort", &View<t_ctxunit>::get_sort)
+        .def("get_min_max", &View<t_ctxunit>::get_min_max)
         .def("get_step_delta", &View<t_ctxunit>::get_step_delta)
         .def("get_column_dtype", &View<t_ctxunit>::get_column_dtype)
         .def("is_column_only", &View<t_ctxunit>::is_column_only);
@@ -129,6 +130,7 @@ PYBIND11_MODULE(libbinding, m)
         .def("get_aggregates", &View<t_ctx0>::get_aggregates)
         .def("get_filter", &View<t_ctx0>::get_filter)
         .def("get_sort", &View<t_ctx0>::get_sort)
+        .def("get_min_max", &View<t_ctx0>::get_min_max)
         .def("get_step_delta", &View<t_ctx0>::get_step_delta)
         .def("get_column_dtype", &View<t_ctx0>::get_column_dtype)
         .def("is_column_only", &View<t_ctx0>::is_column_only);
@@ -155,6 +157,7 @@ PYBIND11_MODULE(libbinding, m)
         .def("get_aggregates", &View<t_ctx1>::get_aggregates)
         .def("get_filter", &View<t_ctx1>::get_filter)
         .def("get_sort", &View<t_ctx1>::get_sort)
+        .def("get_min_max", &View<t_ctx1>::get_min_max)
         .def("get_step_delta", &View<t_ctx1>::get_step_delta)
         .def("get_column_dtype", &View<t_ctx1>::get_column_dtype)
         .def("is_column_only", &View<t_ctx1>::is_column_only);
@@ -181,6 +184,7 @@ PYBIND11_MODULE(libbinding, m)
         .def("get_aggregates", &View<t_ctx2>::get_aggregates)
         .def("get_filter", &View<t_ctx2>::get_filter)
         .def("get_sort", &View<t_ctx2>::get_sort)
+        .def("get_min_max", &View<t_ctx2>::get_min_max)
         .def("get_row_path", &View<t_ctx2>::get_row_path)
         .def("get_step_delta", &View<t_ctx2>::get_step_delta)
         .def("get_column_dtype", &View<t_ctx2>::get_column_dtype)
