@@ -13,7 +13,8 @@ import queue
 import threading
 
 from functools import partial
-from perspective import Table, PerspectiveManager
+from pytest import raises
+from perspective import Table, PerspectiveManager, PerspectiveError
 
 
 def syncify(f):
@@ -76,6 +77,41 @@ class TestAsync(object):
         assert _task() == 5
         tbl.delete()
 
+    def test_async_call_loop(self):
+        tbl = Table({"a": int, "b": float, "c": str})
+        manager = PerspectiveManager()
+        manager.set_loop_callback(TestAsync.loop.add_callback)
+        manager.call_loop(tbl.update, data)
+        manager.host(tbl)
+
+        @syncify
+        def _task():
+            return tbl.size()
+
+        assert _task() == 10
+        tbl.delete()
+
+    def test_async_call_loop_error_if_no_loop(self):
+        tbl = Table({"a": int, "b": float, "c": str})
+        manager = PerspectiveManager()
+
+        with raises(PerspectiveError):
+            # loop not set - errors
+            manager.call_loop(tbl.update, data)
+
+        manager.set_loop_callback(TestAsync.loop.add_callback)
+        manager.call_loop(tbl.update, data)
+        manager.host(tbl)
+
+        @syncify
+        def _task():
+            return tbl.size()
+
+        # subsequent calls to call_loop will work if loop_callback is set.
+        assert _task() == 10
+
+        tbl.delete()
+
     def test_async_multiple_managers_queue_process(self):
         tbl = Table({"a": int, "b": float, "c": str})
         tbl2 = Table({"a": int, "b": float, "c": str})
